function cylinderImplicit = solidCylinderImplicit(A, B, r)

    % Extract coordinates of A and B
    x_a = A(1); y_a = A(2); z_a = A(3);
    x_b = B(1); y_b = B(2); z_b = B(3);

    % Direction vector of the cylinder axis
    d_x = x_b - x_a;
    d_y = y_b - y_a;
    d_z = z_b - z_a;
    d_norm = sqrt(d_x^2 + d_y^2 + d_z^2);
    d_x = d_x / d_norm; d_y = d_y / d_norm; d_z = d_z / d_norm;

    % Function handle for projection of a point onto the axis
    proj_t = @(x, y, z) ((x - x_a) * d_x + (y - y_a) * d_y + (z - z_a) * d_z);

    % Clamped projection (t_clamped)
    t_clamped = @(x, y, z) max(0, min(proj_t(x, y, z), d_norm));

    % Closest point on the axis
    p_x = @(x, y, z) x_a + t_clamped(x, y, z) * d_x;
    p_y = @(x, y, z) y_a + t_clamped(x, y, z) * d_y;
    p_z = @(x, y, z) z_a + t_clamped(x, y, z) * d_z;

    % Squared distance from the axis
    dist2 = @(x, y, z) (x - p_x(x, y, z)).^2 + (y - p_y(x, y, z)).^2 + (z - p_z(x, y, z)).^2;

    % Implicit function for the lateral surface
    lateral_surface = @(x, y, z) dist2(x, y, z) - r^2;

    % Implicit function for the caps
    bottom_cap = @(x, y, z) -((x - x_a) * d_x + (y - y_a) * d_y + (z - z_a) * d_z);
    top_cap = @(x, y, z) ((x - x_b) * d_x + (y - y_b) * d_y + (z - z_b) * d_z);

    % Combined implicit function for the solid cylinder
    cylinderImplicit = @(x, y, z) max(lateral_surface(x, y, z), max(bottom_cap(x, y, z), top_cap(x, y, z)));
end